@@ -1,7 +1,9 @@
 # coding=utf-8
 #
 # catkin_lint
-# Copyright (c) 2013-2021 Fraunhofer FKIE
+# Copyright 2013-2022 Fraunhofer FKIE
+#
+# SPDX-License-Identifier: BSD-3-Clause
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -12,7 +14,7 @@
 #  * Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in the
 #    documentation and/or other materials provided with the distribution.
-#  * Neither the name of the Fraunhofer organization nor the names of its
+#  * Neither the name of the copyright holder nor the names of its
 #    contributors may be used to endorse or promote products derived from
 #    this software without specific prior written permission.
 #
@@ -468,6 +470,10 @@ class ChecksBuildTest(unittest.TestCase):
         self.assertEqual(["MISSING_FILE"], result)
         result = mock_lint(env, pkg, "if(EXISTS \"missing.in\") configure_file(missing.in missing) endif()", checks=cc.generated_files)
         self.assertEqual([], result)
+        result = mock_lint(env, pkg, "if(NOT EXISTS \"missing.in\") else() configure_file(missing.in missing) endif()", checks=cc.generated_files)
+        self.assertEqual([], result)
+        result = mock_lint(env, pkg, "if(NOT EXISTS \"missing1.in\") elseif(NOT EXISTS \"missing2.in\") else() configure_file(missing1.in missing1) configure_file(missing2.in missing2) endif()", checks=cc.generated_files)
+        self.assertEqual([], result)
         result = mock_lint(env, pkg,
                            """
             project(mock)
@@ -477,6 +483,24 @@ class ChecksBuildTest(unittest.TestCase):
             add_executable(${PROJECT_NAME} generated/file.cpp)
             """, checks=cc.source_files)
         self.assertEqual([], result)
+        result = mock_lint(env, pkg,
+                           """
+            project(mock)
+            find_package(catkin REQUIRED)
+            catkin_package()
+            file(GENERATE OUTPUT ${PROJECT_SOURCE_DIR}/generated/file.cpp CONTENT "content")
+            add_executable(${PROJECT_NAME} generated/file.cpp)
+            """, checks=cc.source_files)
+        self.assertEqual([], result)
+        result = mock_lint(env, pkg,
+                           """
+            project(mock)
+            find_package(catkin REQUIRED)
+            catkin_package()
+            file(WRITE ${PROJECT_SOURCE_DIR}/generated/file.cpp "content")
+            add_executable(${PROJECT_NAME} generated/file.cpp)
+            """, checks=cc.source_files)
+        self.assertEqual([], result)
         result = mock_lint(env, pkg,
                            """
             project(mock)
